Trace Viewer V2

{{ selectedSpan.trace_id }} {{ selectedSpan.span_id }} {{ selectedSpan.parent_id || 'None' }} {{ selectedSpan.name }}
{{ selectedSpan.status.code }} View Stack
{{ selectedSpan.start_time}} {{ selectedSpan.end_time }} {{ selectedSpan.duration_ms.toFixed(2) }} ms

    {{ formatAttributes(selectedSpan.attributes) }}

    {{ formatStacktrace(selectedSpan.attributes?.['exception.stacktrace'] || "No stacktrace available") }}